Authors
-------

Created Sep 2024 by Matthias Cuntz extracting it from `pyjams`_.

It is distributed under the MIT License, see LICENSE file.

Copyright (c) 2020- Matthias Cuntz

Contributors
    * `Matthias Cuntz`_, E-mail: mc (at) macu (dot) de

.. _pyjams: https://github.com/mcuntz/pyjams
.. _Matthias Cuntz: https://github.com/mcuntz
